@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1203';
 
 use Moo;
 use strictures 2;
@@ -264,7 +264,7 @@ sub _tokenize {
     my ($sentence) = @_;
     $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
     $sentence =~ s/\d//g;           # Drop digits
-    my @words = grep { $_ } split /\s+/, $sentence;
+    my @words = grep { $_ } map { lc $_ } split /\s+/, $sentence;
     return @words;
 }
 
@@ -294,7 +294,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.1201
+version 0.1203
 
 =head1 SYNOPSIS
 
